summaryrefslogtreecommitdiffstats
path: root/krdc/kservicelocator.h
diff options
context:
space:
mode:
Diffstat (limited to 'krdc/kservicelocator.h')
-rw-r--r--krdc/kservicelocator.h74
1 files changed, 37 insertions, 37 deletions
diff --git a/krdc/kservicelocator.h b/krdc/kservicelocator.h
index db247177..c9439279 100644
--- a/krdc/kservicelocator.h
+++ b/krdc/kservicelocator.h
@@ -21,9 +21,9 @@
#ifndef __KSERVICELOCATOR_H
#define __KSERVICELOCATOR_H
-#include <qobject.h>
-#include <qmap.h>
-#include <qstringlist.h>
+#include <tqobject.h>
+#include <tqmap.h>
+#include <tqstringlist.h>
class KServiceLocatorPrivate;
@@ -39,7 +39,7 @@ class KServiceLocatorPrivate;
* @version $Id$
* @author Tim Jansen, tim@tjansen.de
*/
-class KServiceLocator : public QObject {
+class KServiceLocator : public TQObject {
Q_OBJECT
private:
friend class KServiceLocatorPrivate;
@@ -48,12 +48,12 @@ class KServiceLocator : public QObject {
public:
/**
* Creates a new KServiceLocator.
* @param lang the language to search in, or QString::null for the
* default language
* @param async true to create the service locator in asynchronous
* mode, false otherwise
*/
- KServiceLocator(const QString &lang = QString::null,
+ KServiceLocator(const TQString &lang = TQString::null,
bool async = true);
virtual ~KServiceLocator();
@@ -69,8 +69,8 @@ class KServiceLocator : public QObject {
* @param attributes a list of encoded attributes
* @param attributeMap the attributes will be added to this map
*/
- static void parseAttributeList(const QString &attributes,
- QMap<QString,QString> &attributeMap);
+ static void parseAttributeList(const TQString &attributes,
+ TQMap<TQString,TQString> &attributeMap);
/**
* Decodes the value of an attribute (removes the escape codes). This
@@ -78,24 +78,24 @@ class KServiceLocator : public QObject {
* This function requires the presence of the SLP library, otherwise it
* will return the original value.
* @param value the attribute value to decode
* @return the decoded value. If @p value was QString::null or decoding
* failed, QString::null will be returned
*/
- static QString decodeAttributeValue(const QString &value);
+ static TQString decodeAttributeValue(const TQString &value);
/**
* Parses a comma-separated string of lists, as returned by many signals.
* @param list the comma-separated list
* @return the items as a QStringList
*/
- static QStringList parseCommaList(const QString &list);
+ static TQStringList parseCommaList(const TQString &list);
/**
* Creates a comma-separated string of lists, as required by many functions.
* @param map the items of this list will be converted
* @return the comma-separated list
*/
- static QString createCommaList(const QStringList &values);
+ static TQString createCommaList(const TQStringList &values);
/**
* Escapes a string for use as part of a filter, as described in
@@ -107,7 +107,7 @@ class KServiceLocator : public QObject {
* @param str the string to escape
* @return the escaped string
*/
- static QString escapeFilter(const QString &str);
+ static TQString escapeFilter(const TQString &str);
/**
* Returns true if service location is generally possible.
@@ -120,13 +120,13 @@ class KServiceLocator : public QObject {
* Use this constant for findServiceTypes()'s namingAuthority argument
* to get only services from the default (IANA) naming authority.
*/
- static const QString DEFAULT_AUTHORITY;
+ static const TQString DEFAULT_AUTHORITY;
/**
* Use this constant for findServiceTypes()'s namingAuthority argument
* to get all services,
*/
- static const QString ALL_AUTHORITIES;
+ static const TQString ALL_AUTHORITIES;
/**
* Finds all service types in the given scope with the given naming
@@ -146,12 +146,12 @@ class KServiceLocator : public QObject {
* argument has been omitted all service types
* will be returned.
* @param scopelist a comma-separated list of all scopes that will
* be searched, or QString:null to search in all
* scopes
* @return true if the operation was successful
*/
- bool findServiceTypes(const QString &namingAuthority = QString::null,
- const QString &scopelist = QString::null);
+ bool findServiceTypes(const TQString &namingAuthority = TQString::null,
+ const TQString &scopelist = TQString::null);
/**
* Finds all services in the given scope with the given service type.
@@ -173,13 +173,13 @@ class KServiceLocator : public QObject {
* @param filter a filter in LDAP Search Filter syntax, as described
* in RFC 2254.
* @param scopelist a comma-separated list of all scopes that will
* be searched, or QString:null to search in all
* scopes
* @return true if the operation was successful
*/
- bool findServices(const QString &srvtype,
- const QString &filter = QString::null,
- const QString &scopelist = QString::null);
+ bool findServices(const TQString &srvtype,
+ const TQString &filter = TQString::null,
+ const TQString &scopelist = TQString::null);
/**
* Finds the attributes of the service with the given URL.
@@ -193,12 +193,12 @@ class KServiceLocator : public QObject {
*
* @param serviceURL the URL of the service to search
* @param attributeIds a comma-separated list of attributes to
* retrieve, or QString::null to retrieve all
* attributes
* @return true if the operation was successful
*/
- bool findAttributes(const QString &serviceUrl,
- const QString &attributeIds = QString::null);
+ bool findAttributes(const TQString &serviceUrl,
+ const TQString &attributeIds = TQString::null);
/**
* Finds all scopes that can be searched. Always finds at least
@@ -229,7 +229,7 @@ class KServiceLocator : public QObject {
* types have been discovered.
* @param serviceTypes a comma-separated list of service types
*/
- void foundServiceTypes(QString serviceTypes);
+ void foundServiceTypes(TQString serviceTypes);
/**
* Called by findServices() each time a service has been
@@ -237,7 +237,7 @@ class KServiceLocator : public QObject {
* @param serviceUrl the service url
* @param lifetime the lifetime of the service in seconds
*/
- void foundService(QString serviceUrl,
+ void foundService(TQString serviceUrl,
int lifetime);
/**
@@ -247,15 +247,15 @@ class KServiceLocator : public QObject {
* @param attributes an attribute map (see parseAttributeList() and
* decodeAttributeValue())
*/
- void foundAttributes(QString serviceUrl,
- QString attributes);
+ void foundAttributes(TQString serviceUrl,
+ TQString attributes);
/**
* Called by findScopes() when the scopes have been discovered.
* @param scopeList a list of valid scopes, empty if an error
* occurred
*/
- void foundScopes(QStringList scopeList);
+ void foundScopes(TQStringList scopeList);
/**
@@ -292,15 +292,15 @@ class KServiceLocator : public QObject {
void lastAttributesSignal(bool success);
protected:
- virtual void customEvent(QCustomEvent *);
+ virtual void customEvent(TQCustomEvent *);
private:
- void emitFoundServiceTypes(QString serviceTypes);
- void emitFoundService(QString serviceUrl,
+ void emitFoundServiceTypes(TQString serviceTypes);
+ void emitFoundService(TQString serviceUrl,
int lifetime);
- void emitFoundAttributes(QString serviceUrl,
- QString attributes);
- void emitFoundScopes(QStringList scopeList);
+ void emitFoundAttributes(TQString serviceUrl,
+ TQString attributes);
+ void emitFoundScopes(TQStringList scopeList);
void emitLastServiceTypeSignal(bool success);
void emitLastServiceSignal(bool success);
void emitLastAttributesSignal(bool success);
@@ -48,12 +48,12 @@ class KServiceLocator : public QObject {
/**
* Creates a new KServiceLocator.
- * @param lang the language to search in, or QString::null for the
+ * @param lang the language to search in, or TQString::null for the
* default language
* @param async true to create the service locator in asynchronous
@@ -78,24 +78,24 @@ class KServiceLocator : public QObject {
* will return the original value.
* @param value the attribute value to decode
- * @return the decoded value. If @p value was QString::null or decoding
- * failed, QString::null will be returned
+ * @return the decoded value. If @p value was TQString::null or decoding
+ * failed, TQString::null will be returned
*/
@@ -146,12 +146,12 @@ class KServiceLocator : public QObject {
* will be returned.
* @param scopelist a comma-separated list of all scopes that will
- * be searched, or QString:null to search in all
+ * be searched, or TQString:null to search in all
* scopes
* @return true if the operation was successful
@@ -173,13 +173,13 @@ class KServiceLocator : public QObject {
* in RFC 2254.
* @param scopelist a comma-separated list of all scopes that will
- * be searched, or QString:null to search in all
+ * be searched, or TQString:null to search in all
* scopes
* @return true if the operation was successful
@@ -193,12 +193,12 @@ class KServiceLocator : public QObject {
* @param serviceURL the URL of the service to search
* @param attributeIds a comma-separated list of attributes to
- * retrieve, or QString::null to retrieve all
+ * retrieve, or TQString::null to retrieve all
* attributes
* @return true if the operation was successful